#!/bin/bash
set -e
PROG_NAME=`basename $0`
DIR_NAME=`dirname $0`
usage() {
cat << EOF >&2
 usage: $PROG_NAME -s <serverHostName:serverPort> -r <roleName> -l <logDir> -n <numEventsPerMillSec>
EOF
}

while getopts "s:r:l:n:" option
do
  case $option in
    s)
      SERVER_ADDR=$OPTARG
      ;;
    r)
      ROLE_NAME=$OPTARG
      ;;
    l)
      LOG_DIR=$OPTARG
      ;;
    n)
      NUM_EVENTS_PER_MS=$OPTARG
      ;;
    ?)
      usage
      exit
  esac
done

validate() {
  if [ -z $ROLE_NAME ] || [ -z $SERVER_ADDR ] || [ -z $LOG_DIR ] || [ -z $NUM_EVENTS_PER_MS ]
  then
    usage
    exit 1
  fi
}

modify_properties_file() {
  perl -pi -e "s#\{\{SERVER_ADDRESS}}#$SERVER_ADDR#g" $DIR_NAME/../conf/navigator.client.properties
  echo "navigator.client.roleName"=$ROLE_NAME >> $DIR_NAME/../conf/navigator.client.properties
  echo "navigator.client.csvLogFilePath"=$LOG_DIR >> $DIR_NAME/../conf/navigator.client.properties
}

delete_existing_logs() {
  echo "Deleting existing log files"
  rm -rf $LOG_DIR
  mkdir -p $LOG_DIR
}

validate
modify_properties_file
delete_existing_logs

exec java -cp "$DIR_NAME/../lib/*" com.cloudera.navigator.audit.MockAgentSetup --prop-file \
 "$DIR_NAME/../conf/navigator.client.properties" --numEventsPerMS $NUM_EVENTS_PER_MS --timeToRun 600
